.. CuBIDS documentation master file

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   about
   installation
   usage
   cli
   example
   examples
   ../CONTRIBUTING
   ../AUTHORS
   ../HISTORY
   glossary
   api
